[![Code style: black](https://img.shields.io/badge/python%20style-black-000000.svg)](https://github.com/psf/black)
[![Code style: djlint](https://img.shields.io/badge/html%20style-djlint-black.svg)](https://www.djlint.com)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/NEMO-CE?label=python)](https://www.python.org/downloads/release/python-3110/)
[![PyPI](https://img.shields.io/pypi/v/nemo-ce?label=pypi%20version)](https://pypi.org/project/NEMO/)

See the [wiki](https://gitlab.com/nemo-community/nemo-ce/-/wikis/home) for installation steps and new features